summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorDave Watson <davejwatson@fb.com>2017-08-16 11:27:43 -0700
committerDave Watson <davejwatson@fb.com>2017-08-16 11:27:43 -0700
commit644cce3d722e677073d0529c5a969e025888af86 (patch)
tree318a049b2311a1d207d28b93fff409dd4ee31220 /tests
parent4e8b7a595e144e905fd9c8aed053d7529afb78a4 (diff)
downloadlibunwind-644cce3d722e677073d0529c5a969e025888af86.tar.gz
half finished unw_local_init2
Diffstat (limited to 'tests')
-rw-r--r--tests/Ltest-init-local-signal.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/Ltest-init-local-signal.c b/tests/Ltest-init-local-signal.c
index b834d44d..d23d66f9 100644
--- a/tests/Ltest-init-local-signal.c
+++ b/tests/Ltest-init-local-signal.c
@@ -25,12 +25,12 @@ int stepper(unw_cursor_t* c) {
/* Verify that we can step from both ucontext, and from getcontext()
* roughly the same. This tests that the IP from ucontext is used
* correctly (see impl of unw_init_local_signal) */
void handler(int num, siginfo_t* info, void* ucontext) {
unw_cursor_t c;
unw_context_t context;
unw_getcontext(&context);
- int ret = unw_init_local_signal(&c, ucontext);
+ int ret = unw_init_local2(&c, ucontext, UNW_INIT_SIGNAL_FRAME);
assert(!ret);
int ucontext_steps = stepper(&c);
@@ -25,12 +25,12 @@ int stepper(unw_cursor_t* c) {
/* Verify that we can step from both ucontext, and from getcontext()
* roughly the same. This tests that the IP from ucontext is used
- * correctly (see impl of unw_init_local_signal) */
+ * correctly (see impl of unw_init_local2) */
void handler(int num, siginfo_t* info, void* ucontext) {
unw_cursor_t c;